nagios_host 'ajtmh.org' do
	options 'use' => 'noping-host-https',
		'alias' => 'AJTMH',
		'address' => 'ajtmh.org',
		'contact_groups' => 'cs_escalation,astmh',
		'notes' => 'AJTMH Live Site',
		'notes_url' => 'https://safari.atlassian.net/wiki/spaces/ASTMH/pages/1340276861/ASTMH+Server+Setup+Page'
end
nagios_host 'admin.ajtmh.org' do
	options 'use' => 'noping-host-https',
		'alias' => 'AJTMH MGMT',
		'address' => 'admin.ajtmh.org',
		'contact_groups' => 'cs_escalation,astmh',
		'notes' => 'AJTMH Production Management Portal',
		'notes_url' => 'https://safari.atlassian.net/wiki/spaces/ASTMH/pages/1340276861/ASTMH+Server+Setup+Page'
end
nagios_host 'ams.ajtmh.org' do
	options 'use' => 'noping-host-https',
		'alias' => 'AJTMH AMS',
		'address' => 'ams.ajtmh.org',
		'contact_groups' => 'cs_escalation,astmh',
		'notes' => 'AJTMH Production AMS',
		'notes_url' => 'https://safari.atlassian.net/wiki/spaces/ASTMH/pages/1340276861/ASTMH+Server+Setup+Page'
end
#------------------------------------------------------------------------------------
# HOMEPAGE
# checks the homepage of the live AJTMH site and checks for the string 'Tropical Medicine and Hygiene'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'ajtmh.org-Live Homepage' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'ajtmh.org',
		'display_name' => 'Live Homepage',
		'check_command' => 'https_content_check_basic_auth!astmh:astmh2020!/!"Tropical Medicine and Hygiene"!10!20!',
		'contact_groups' => 'cs_escalation,astmh',
		'notes' => 'AJTMH Live Site',
		'notes_url' => 'https://ajtmh.org'
end
#------------------------------------------------------------------------------------
# HOMEPAGE (NODE 1)
# checks the homepage of the live astmh site on the first web node and checks for the string 'Tropical Medicine and Hygiene'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'ajtmh.org-Live Homepage: astmh-web-1' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'ajtmh.org',
		'display_name' => 'Live Homepage: astmh-web-1',
		'check_command' => 'https_content_check_basic_auth_single_node!astmh:astmh2020!/!"Tropical Medicine and Hygiene"!10!20!astmh-web-1-live!astmh-web-1.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,astmh',
		'notes' => 'AJTMH Live Site: astmh-web-1',
		'notes_url' => 'https://ajtmh.org'
end
#------------------------------------------------------------------------------------
# HOMEPAGE (NODE 2)
# checks the homepage of the live astmh site on the sercond web node and checks for the string 'Tropical Medicine and Hygiene'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'ajtmh.org-Live Homepage: astmh-web-2' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'ajtmh.org',
		'display_name' => 'Live Homepage: astmh-web-2',
		'check_command' => 'https_content_check_basic_auth_single_node!astmh:astmh2020!/!"Tropical Medicine and Hygiene"!10!20!astmh-web-2-live!astmh-web-2.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,astmh',
		'notes' => 'AJTMH Live Site: astmh-web-2',
		'notes_url' => 'https://ajtmh.org'
end
#------------------------------------------------------------------------------------
# SEARCH
# Checks the search of the live AJTMH site and checks for the string 'Tropical Medicine and Hygiene'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'ajtmh.org-Live Search' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'ajtmh.org',
		'display_name' => 'Live Search',
		'check_command' => 'https_content_check_basic_auth!astmh:astmh2020!/search!Browse!10!20!',
		'contact_groups' => 'cs_escalation,astmh',
		'notes' => 'AJTMH Live Site',
		'notes_url' => 'https://ajtmh.org/search'
end
#------------------------------------------------------------------------------------
# SEARCH (NODE 1)
# Checks the search of the live astmh site on the first web node and checks for the string 'Tropical Medicine and Hygiene'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'ajtmh.org-Live Search: astmh-web-1' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'ajtmh.org',
		'display_name' => 'Live search: astmh-web-1',
		'check_command' => 'https_content_check_basic_auth_single_node!astmh:astmh2020!/search!Browse!10!20!astmh-web-1-live!astmh-web-1.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,astmh',
		'notes' => 'AJTMH Live Site: astmh-web-1',
		'notes_url' => 'https://ajtmh.org/search'
end
#------------------------------------------------------------------------------------
# SEARCH (NODE 2)
# Checks the search of the live astmh site on the second web node and checks for the string 'Tropical Medicine and Hygiene'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'ajtmh.org-Live Search: astmh-web-2' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'ajtmh.org',
		'display_name' => 'Live search: astmh-web-2',
		'check_command' => 'https_content_check_basic_auth_single_node!astmh:astmh2020!/search!Browse!10!20!astmh-web-2-live!astmh-web-2.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,astmh',
		'notes' => 'AJTMH Live Site: astmh-web-2',
		'notes_url' => 'https://ajtmh.org/search'
end
#------------------------------------------------------------------------------------
# CONTENT VIEW
# checks the content view of the live AJTMH site and checks for the string 'Tropical Medicine and Hygiene'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'ajtmh.org-Live content view' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'ajtmh.org',
		'display_name' => 'Live content view',
		'check_command' => 'https_content_check_basic_auth!astmh:astmh2020!/view/journals/tpmd/104/1/article-p5.xml!Blood!10!20!',
		'contact_groups' => 'cs_escalation,astmh',
		'notes' => 'AJTMH Live Site',
		'notes_url' => 'https://ajtmh.org/view/journals/tpmd/104/1/article-p5.xml'
end
#------------------------------------------------------------------------------------
# CONTENT VIEW (NODE 1)
# checks the content view of the live astmh site on the first web node and checks for the string 'Tropical Medicine and Hygiene'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'ajtmh.org-Live content view: astmh-web-1' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'ajtmh.org',
		'display_name' => 'Live content view: astmh-web-1',
		'check_command' => 'https_content_check_basic_auth_single_node!astmh:astmh2020!/view/journals/tpmd/104/1/article-p5.xml!Blood!10!20!astmh-web-1-live!astmh-web-1.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,astmh',
		'notes' => 'AJTMH Live Site: astmh-web-1',
		'notes_url' => 'https://ajtmh.org/view/journals/tpmd/104/1/article-p5.xml'
end
#------------------------------------------------------------------------------------
# CONTENT VIEW (NODE 2)
# checks the content view of the live astmh site on the sedmond web node and checks for the string 'Tropical Medicine and Hygiene'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'ajtmh.org-Live content view: astmh-web-2' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'ajtmh.org',
		'display_name' => 'Live content view: astmh-web-2',
		'check_command' => 'https_content_check_basic_auth_single_node!astmh:astmh2020!/view/journals/tpmd/104/1/article-p5.xml!Blood!10!20!astmh-web-2-live!astmh-web-2.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,astmh',
		'notes' => 'AJTMH Live Site: astmh-web-2',
		'notes_url' => 'https://ajtmh.org//view/journals/tpmd/104/1/article-p5.xml'
end
#------------------------------------------------------------------------------------
# LOADER
# Checks a loader login page and looks for the string 'Login' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'ajtmh.org-Production Loader' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'admin.ajtmh.org',
		'display_name' => 'Production Loader',
		'check_command' => 'check_loader_auth!admin.ajtmh.org!/login!astmh:astmh2020!"ASTMH"!20!10',
		'contact_groups' => 'admins_email_only,astmh',
		'notes' => 'AJTMH Live Loader',
		'notes_url' => 'https://admin.ajtmh.org/login'
end
#------------------------------------------------------------------------------------
# STAGING
# Checks the staging site homepage and looks for the string 'Tropical Medicine and Hygiene' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'ajtmh.org-Staging Homepage' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'ajtmh.org',
		'display_name' => 'Staging Homepage',
		'check_command' => 'check_staging_auth!staging.ajtmh.org!astmh:astmh2020!"Tropical Medicine and Hygiene"!20!10',
		'contact_groups' => 'admins_email_only,astmh',
		'notes' => 'AJTMH Staging Site',
		'notes_url' => 'staging.ajtmh.org'
end
#------------------------------------------------------------------------------------
# AMX
# Checks the production amx homepage and looks for the string 'AMS' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'ajtmh.org-Production AMX' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'ams.ajtmh.org',
		'display_name' => 'Production AMX',
		'check_command' => 'check_loader_auth!ams.ajtmh.org!/login!astmh:astmh2020!AMS!20!10',
		'contact_groups' => 'admins_email_only,astmh',
		'notes' => 'AJTMH AMX',
		'notes_url' => 'https://ams.ajtmh.org/login'
end
#------------------------------------------------------------------------------------
# FAIL OPEN
# Checks the production homepage and makes sure we're not in fail open by checking
# that the string "Provisional Account" is NOT in the page.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'ajtmh.org-Live Site Fail Open' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'ajtmh.org',
		'display_name' => 'Live Site Fail Open',
		'check_command' => 'http_negate_content_check_basic_auth!ajtmh.org!astmh:astmh2020!"provisional account"',
		'contact_groups' => 'admins_email_only,astmh',
		'notes' => 'AJTMH Live Site Failopen',
		'notes_url' => 'https://ajtmh.org/'
end
#------------------------------------------------------------------------------------
# HOMEPAGE (Node 3)
# Checks the homepage of the live ajtmh site on the bot web node and checks for the string 'ASTMH'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'ajtmh.org-Live Homepage: astmh-web-3 bot node' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'ajtmh.org',
		'display_name' => 'Live Homepage: astmh-web-3',
		'check_command' => 'https_content_check_basic_auth_single_node_bot!astmh:2020!/!ASTMH!10!20!astmh-web-3-live!astmh-web-3.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,astmh',
		'notes' => 'astmh Site: astmh-web-3',
		'notes_url' => 'https://www.ajtmh.org/'
end
#------------------------------------------------------------------------------------
# SEARCH (NODE 3)
# Checks the search of the live ajtmh site on the first bot web node and checks for the string 'Browse'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'ajtmh.org-Live Search: astmh-web-3 bot node' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'ajtmh.org',
		'display_name' => 'Live Search: astmh-web-3',
		'check_command' => 'https_content_check_basic_auth_single_node_bot!astmh:2020!/search!Browse!10!20!astmh-web-3-live!astmh-web-3.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,astmh',
		'notes' => 'astmh Site: astmh-web-3',
		'notes_url' => 'https://www.ajtmh.org/'
end
#------------------------------------------------------------------------------------
# CONTENT VIEW (NODE 3)
# checks the content view of the live astmh site on the first web node and checks for the string 'Tropical Medicine and Hygiene'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'ajtmh.org-Live content view: astmh-web-3' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'ajtmh.org',
		'display_name' => 'Live content view: astmh-web-3',
		'check_command' => 'https_content_check_basic_auth_single_node_bot!astmh:astmh2020!/view/journals/tpmd/104/1/article-p5.xml!Blood!10!20!astmh-web-3-live!astmh-web-3.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,astmh',
		'notes' => 'AJTMH Live Site: astmh-web-3',
		'notes_url' => 'https://ajtmh.org/view/journals/tpmd/104/1/article-p5.xml'
end
