nagios_host 'thejns.org' do
	options 'use' => 'noping-host-https',
		'alias' => 'JNS Homepage',
		'address' => 'thejns.org',
		'contact_groups' => 'cs_escalation,jns',
		'notes' => 'JNS Live Site',
		'notes_url' => 'https://safari.atlassian.net/wiki/spaces/JNS/pages/230195261/Server+Setup+-+Journal+of+Neurosurgery+JNS'
end
nagios_host 'admin.thejns.org' do
	options 'use' => 'noping-host-https',
		'alias' => 'JNS MGMT Portal',
		'address' => 'admin.thejns.org',
		'contact_groups' => 'cs_escalation,jns',
		'notes' => 'JNS Production Management Portal',
		'notes_url' => 'https://safari.atlassian.net/wiki/spaces/JNS/pages/230195261/Server+Setup+-+Journal+of+Neurosurgery+JNS'
end
nagios_host 'ams.thejns.org' do
	options 'use' => 'noping-host-https',
		'alias' => 'JNS AMX',
		'address' => 'ams.thejns.org',
		'contact_groups' => 'cs_escalation,jns',
		'notes' => 'JNS Production AMS',
		'notes_url' => 'https://safari.atlassian.net/wiki/spaces/JNS/pages/230195261/Server+Setup+-+Journal+of+Neurosurgery+JNS'
end
#------------------------------------------------------------------------------------
# HOMEPAGE
# checks the homepage of the live JNS site and checks for the string 'Journal of Neurosurgery'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'thejns.org-Live Homepage' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'thejns.org',
		'display_name' => 'Live Homepage',
		'check_command' => 'https_content_check_basic_auth!jns:jns2018!/!"Journal of Neurosurgery"!10!20!',
		'contact_groups' => 'cs_escalation,jns',
		'notes' => 'JNS Live Site',
		'notes_url' => 'https://thejns.org'
end
#------------------------------------------------------------------------------------
# HOMEPAGE (NODE 1)
# checks the homepage of the live jns site on the first web node and checks for the string 'Journal of Neurosurgery'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'thejns.org-Live Homepage: web-25' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'thejns.org',
		'display_name' => 'Live Homepage: web-25',
		'check_command' => 'https_content_check_basic_auth_single_node!jns:jns2018!/!"Journal of Neurosurgery"!10!20!jns-web-live25!10.200.3.184!',
		'contact_groups' => 'admins_email_only,jns',
		'notes' => 'JNS Live Site: web-25',
		'notes_url' => 'https://thejns.org'
end
#------------------------------------------------------------------------------------
# HOMEPAGE (NODE 2)
# checks the homepage of the live jns site on the sercond web node and checks for the string 'Journal of Neurosurgery'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'thejns.org-Live Homepage: web-11' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'thejns.org',
		'display_name' => 'Live Homepage: web-11',
		'check_command' => 'https_content_check_basic_auth_single_node!jns:jns2018!/!"Journal of Neurosurgery"!10!20!jns-web-live11!10.200.3.96!',
		'contact_groups' => 'admins_email_only,jns',
		'notes' => 'JNS Live Site: web-11',
		'notes_url' => 'https://thejns.org'
end
#------------------------------------------------------------------------------------
# SEARCH
# Checks the search of the live JNS site and checks for the string 'Journal of Neurosurgery'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'thejns.org-Live Search' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'thejns.org',
		'display_name' => 'Live Search',
		'check_command' => 'https_content_check_basic_auth!jns:jns2018!/browse!browse!10!20!',
		'contact_groups' => 'cs_escalation,jns',
		'notes' => 'JNS Live Site',
		'notes_url' => 'https://thejns.org/browse'
end
#------------------------------------------------------------------------------------
# SEARCH (NODE 1)
# Checks the search of the live jns site on the first web node and checks for the string 'Journal of Neurosurgery'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'thejns.org-Live Search: web-25' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'thejns.org',
		'display_name' => 'Live search: web-25',
		'check_command' => 'https_content_check_basic_auth_single_node!jns:jns2018!/browse!browse!10!20!jns-web-live25!10.200.3.184!',
		'contact_groups' => 'admins_email_only,jns',
		'notes' => 'JNS Live Site: web-25',
		'notes_url' => 'https://thejns.org/browse'
end
#------------------------------------------------------------------------------------
# SEARCH (NODE 2)
# Checks the search of the live jns site on the second web node and checks for the string 'Journal of Neurosurgery'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'thejns.org-Live search: web-11' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'thejns.org',
		'display_name' => 'Live search: web-11',
		'check_command' => 'https_content_check_basic_auth_single_node!jns:jns2018!/browse!browse!10!20!jns-web-live11!10.200.3.96!',
		'contact_groups' => 'admins_email_only,jns',
		'notes' => 'JNS Live Site: web-11',
		'notes_url' => 'https://thejns.org/browse'
end
#------------------------------------------------------------------------------------
# CONTENT VIEW
# checks the content view of the live JNS site and checks for the string 'Journal of Neurosurgery'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'thejns.org-Live content view' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'thejns.org',
		'display_name' => 'Live content view',
		'check_command' => 'https_content_check_basic_auth!jns:jns2018!/abstract/journals/j-neurosurg/2/1/article-p47.xml!Exanopic!10!20!',
		'contact_groups' => 'cs_escalation,jns',
		'notes' => 'JNS Live Site',
		'notes_url' => 'https://thejns.org/abstract/journals/j-neurosurg/2/1/article-p47.xml'
end
#------------------------------------------------------------------------------------
# CONTENT VIEW (NODE 1)
# checks the content view of the live jns site on the first web node and checks for the string 'Journal of Neurosurgery'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'thejns.org-Live content view: web-25' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'thejns.org',
		'display_name' => 'Live content view: web-25',
		'check_command' => 'https_content_check_basic_auth_single_node!jns:jns2018!/abstract/journals/j-neurosurg/2/1/article-p47.xml!Exanopic!10!20!jns-web-live25!10.200.3.184!',
		'contact_groups' => 'admins_email_only,jns',
		'notes' => 'JNS Live Site: web-25',
		'notes_url' => 'https://thejns.org/abstract/journals/j-neurosurg/2/1/article-p47.xml'
end
#------------------------------------------------------------------------------------
# CONTENT VIEW (NODE 2)
# checks the content view of the live jns site on the sedmond web node and checks for the string 'Journal of Neurosurgery'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'thejns.org-Live content view: web-11' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'thejns.org',
		'display_name' => 'Live content view: web-11',
		'check_command' => 'https_content_check_basic_auth_single_node!jns:jns2018!/abstract/journals/j-neurosurg/2/1/article-p47.xml!Exanopic!10!20!jns-web-live11!10.200.3.96!',
		'contact_groups' => 'admins_email_only,jns',
		'notes' => 'JNS Live Site: web-11',
		'notes_url' => 'https://thejns.org/abstract/journals/j-neurosurg/2/1/article-p47.xml'
end
#------------------------------------------------------------------------------------
# LOADER
# Checks a loader login page and looks for the string 'Login' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'thejns.org-Production Loader' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'admin.thejns.org',
		'display_name' => 'Production Loader',
		'check_command' => 'check_loader_auth!admin.thejns.org!/login!jns:jns2018!"JNS PROD"!20!10',
		'contact_groups' => 'admins_email_only,jns',
		'notes' => 'JNS Live Loader',
		'notes_url' => 'https://admin.thejns.org/login'
end
#------------------------------------------------------------------------------------
# STAGING
# Checks the staging site homepage and looks for the string 'Journal of Neurosurgery' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'thejns.org-Staging Homepage' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'thejns.org',
		'display_name' => 'Staging Homepage',
		'check_command' => 'check_staging_auth!staging.thejns.org!jns:jns2018!"Journal of Neurosurgery"!20!10',
		'contact_groups' => 'admins_email_only,jns',
		'notes' => 'JNS Staging Site',
		'notes_url' => 'staging.thejns.org'
end
#------------------------------------------------------------------------------------
# AMX
# Checks the production amx homepage and looks for the string 'AMS' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'thejns.org-Production AMX' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'ams.thejns.org',
		'display_name' => 'Production AMX',
		'check_command' => 'check_loader_auth!ams.thejns.org!/login!jns:jns2018!AMS!20!10',
		'contact_groups' => 'admins_email_only,jns',
		'notes' => 'JNS AMX',
		'notes_url' => 'https://ams.thejns.org/login'
end
#------------------------------------------------------------------------------------
# FAIL OPEN
# Checks the production homepage and makes sure we're not in fail open by checking
# that the string "Provisional Account" is NOT in the page.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'thejns.org-Live Site Fail Open' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'thejns.org',
		'display_name' => 'Live Site Fail Open',
		'check_command' => 'http_negate_content_check_basic_auth!thejns.org!jns:jns2018!"provisional account"',
		'contact_groups' => 'admins_email_only,jns',
		'notes' => 'JNS Live Site Failopen',
		'notes_url' => 'https://thejns.org/'
end
